@@ -8,12 +8,12 @@
     SPDX-License-Identifier: GPL-2.0-only
 */
 
-#include <../src/ksieve/parser.h>
+#include "parser.h"
 #include <config-libksieve.h> // SIZEOF_UNSIGNED_LONG
 using KSieve::Parser;
 
-#include <../src/ksieve/error.h>
-#include <../src/ksieve/scriptbuilder.h>
+#include "error.h"
+#include "scriptbuilder.h"
 
 #include <QString>
 
@@ -436,7 +436,7 @@ public:
 
     ~VerifyingScriptBuilder() override = default;
 
-    Q_REQUIRED_RESULT bool ok() const
+    [[nodiscard]] bool ok() const
     {
         return mOk;
     }
@@ -571,7 +571,7 @@ public:
 
 private:
     Q_DISABLE_COPY(VerifyingScriptBuilder)
-    Q_REQUIRED_RESULT const TestCase::Response &currentResponse() const
+    [[nodiscard]] const TestCase::Response &currentResponse() const
     {
         assert(mNextResponse <= MAX_RESPONSES);
         return mTestCase.responses[mNextResponse];
